/* UndoListener.java
 * =========================================================================
 * This file is part of the SWIRL Library - http://swirl-lib.sourceforge.net
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 * 
 */

package be.ugent.caagt.swirl.undoredo;

import java.util.EventListener;

/**
 * Listens to changes in the state of an {@link UndoManager}. Listeners
 * must be registered with an undo manager if they want to be notified
 * of any changes.<p>
 *
 * <b>Note:</b> It is the responsibility of
 * the undo listener to keep track of the undo manager being listened
 * to.
 */
public interface UndoListener extends EventListener {
     
    /**
     * Called after a change of state in the {@link UndoManager}
     * which is listened to, i.e., when undoable changes are added or removed
     * from the list, when the list position is changed and when 
     * the marked position changes.
     */
    public void undoStateChanged ();
    
}
